use crate::pos::Pos;

#[derive(Clone, PartialEq, Debug)]
pub struct Node {
    pub kind: NodeKind,
    pub pos: Pos,
}

impl Node {
    pub fn new(kind: NodeKind, pos: Pos) -> Self {
        Self { kind, pos }
    }
}

#[derive(Clone, PartialEq, Debug)]
pub enum NodeKind {
    Error,
    Id(u64),
    Int(i64),
    Str(String),
    Group(Box<Node>),
    Block(Vec<Node>),
    Call {
        subject: Box<Node>,
        args: Vec<Node>,
    },
    If {
        cond: Box<Node>,
        truthy: Box<Node>,
        falsy: Option<Box<Node>>,
    },
    Loop {
        body: Box<Node>,
    },
    Break,
    Assign {
        subject: Box<Node>,
        value: Box<Node>,
    },
    Let {
        subject: Box<Node>,
        value: Box<Node>,
    },
    Fn {
        subject: Box<Node>,
        params: Vec<Node>,
        return_typ: Box<Node>,
        body: Box<Node>,
    },
    Return {
        value: Option<Box<Node>>,
    },
    Param {
        subject: Box<Node>,
        typ: Option<Box<Node>>,
    },
}
